@@ -35,6 +35,8 @@ class AlbArnTarget(
 ):
     '''A single Application Load Balancer as the target for load balancing.
 
+    :exampleMetadata: fixture=_generated
+
     Example::
 
         # The code below shows an example of how to instantiate this type.
@@ -74,6 +76,8 @@ class AlbTarget(
 ):
     '''A single Application Load Balancer as the target for load balancing.
 
+    :exampleMetadata: infused
+
     Example::
 
         import aws_cdk.aws_elasticloadbalancingv2_targets as targets
@@ -133,6 +137,8 @@ class InstanceIdTarget(
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can connect to the instance.
 
+    :exampleMetadata: fixture=_generated
+
     Example::
 
         # The code below shows an example of how to instantiate this type.
@@ -189,6 +195,8 @@ class InstanceTarget(
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceTarget",
 ):
     '''
+    :exampleMetadata: fixture=_generated
+
     Example::
 
         # The code below shows an example of how to instantiate this type.
@@ -229,6 +237,8 @@ class IpTarget(
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can send packets to the IP address.
 
+    :exampleMetadata: fixture=_generated
+
     Example::
 
         # The code below shows an example of how to instantiate this type.
@@ -302,6 +312,8 @@ class LambdaTarget(
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.LambdaTarget",
 ):
     '''
+    :exampleMetadata: infused
+
     Example::
 
         import aws_cdk.aws_lambda as lambda_
